/*
 * Copyright (c) 2010-2011, The MiCode Open Source Community (www.micode.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// 定义包名
package net.micode.notes.gtask.data;

// 导入Cursor类用于数据库操作
import android.database.Cursor;

// 导入JSON相关类
import org.json.JSONObject;

// 声明一个抽象类Node
public abstract class Node {
    // 定义同步操作的常量
    public static final int SYNC_ACTION_NONE = 0; // 无同步操作
    public static final int SYNC_ACTION_ADD_REMOTE = 1; // 从远程添加
    public static final int SYNC_ACTION_ADD_LOCAL = 2; // 从本地添加
    public static final int SYNC_ACTION_DEL_REMOTE = 3; // 从远程删除
    public static final int SYNC_ACTION_DEL_LOCAL = 4; // 从本地删除
    public static final int SYNC_ACTION_UPDATE_REMOTE = 5; // 从远程更新
    public static final int SYNC_ACTION_UPDATE_LOCAL = 6; // 从本地更新
    public static final int SYNC_ACTION_UPDATE_CONFLICT = 7; // 更新冲突
    public static final int SYNC_ACTION_ERROR = 8; // 错误状态

    // 定义私有成员变量
    private String mGid; // 唯一标识符
    private String mName; // 名称
    private long mLastModified; // 最后修改时间
    private boolean mDeleted; // 是否已删除

    // Node类的构造函数
    public Node() {
        mGid = null; // 初始化GID为null
        mName = ""; // 初始化名称为空字符串
        mLastModified = 0; // 初始化最后修改时间为0
        mDeleted = false; // 初始化删除状态为false
    }

    // 抽象方法，返回创建操作的JSON对象
    public abstract JSONObject getCreateAction(int actionId);

    // 抽象方法，返回更新操作的JSON对象
    public abstract JSONObject getUpdateAction(int actionId);

    // 抽象方法，通过远程JSON设置内容
    public abstract void setContentByRemoteJSON(JSONObject js);

    // 抽象方法，通过本地JSON设置内容
    public abstract void setContentByLocalJSON(JSONObject js);

    // 抽象方法，从内容获取本地JSON
    public abstract JSONObject getLocalJSONFromContent();

    // 抽象方法，从数据库游标获取同步操作
    public abstract int getSyncAction(Cursor c);

    // 设置GID的方法
    public void setGid(String gid) {
        this.mGid = gid; // 赋值
    }

    // 设置名称的方法
    public void setName(String name) {
        this.mName = name; // 赋值
    }

    // 设置最后修改时间的方法
    public void setLastModified(long lastModified) {
        this.mLastModified = lastModified; // 赋值
    }

    // 设置删除状态的方法
    public void setDeleted(boolean deleted) {
        this.mDeleted = deleted; // 赋值
    }

    // 获取GID的方法
    public String getGid() {
        return this.mGid; // 返回GID
    }

    // 获取名称的方法
    public String getName() {
        return this.mName; // 返回名称
    }

    // 获取最后修改时间的方法
    public long getLastModified() {
        return this.mLastModified; // 返回最后修改时间
    }

    // 获取删除状态的方法
    public boolean getDeleted() {
        return this.mDeleted; // 返回删除状态
    }
}
